#[non_exhaustive]pub enum Layer {
Invalid,
Background,
Canvas,
Widget,
Mdi,
Popup,
Overlay,
Window,
}Expand description
Describes the layer of a component
These enumerated “layer values” are used when determining which UI rendering layer a component is drawn into, which can help in making determinations of when components occlude one another.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Invalid
The object does not have a layer
Background
This layer is reserved for the desktop background
Canvas
This layer is used for Canvas components
Widget
This layer is normally used for components
Mdi
This layer is used for layered components
Popup
This layer is used for popup components, such as menus
Overlay
This layer is reserved for future use.
Window
This layer is used for toplevel windows.