#[non_exhaustive]pub enum Live {
None,
Polite,
Assertive,
}Available on crate feature
v2_50 only.Expand description
Enumeration used to indicate a type of live region and how assertive it should be in terms of speaking notifications. Currently, this is only used for “notification” events, but it may be used for additional purposes in the future.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
No live region.
Polite
This live region should be considered polite.
Assertive
This live region should be considered assertive.