ScrollType

Enum ScrollType 

#[non_exhaustive]
pub enum ScrollType { TopLeft, BottomRight, TopEdge, BottomEdge, LeftEdge, RightEdge, Anywhere, }
Available on crate feature v2_30 only.
Specifies where an object should be placed on the screen when using scroll_to.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


TopLeft

Scroll the object vertically and horizontally to bring its top left corner to the top left corner of the window.



BottomRight

Scroll the object vertically and horizontally to bring its bottom right corner to the bottom right corner of the window.



TopEdge

Scroll the object vertically to bring its top edge to the top edge of the window.



BottomEdge

Scroll the object vertically to bring its bottom edge to the bottom edge of the window.



LeftEdge

Scroll the object vertically and horizontally to bring its left edge to the left edge of the window.



RightEdge

Scroll the object vertically and horizontally to bring its right edge to the right edge of the window.



Anywhere

Scroll the object vertically and horizontally so that as much as possible of the object becomes visible. The exact placement is determined by the application.