TextAttribute

Enum TextAttribute 

#[non_exhaustive]
pub enum TextAttribute {
Show 30 variants Invalid, LeftMargin, RightMargin, Indent, Invisible, Editable, PixelsAboveLines, PixelsBelowLines, PixelsInsideWrap, BgFullHeight, Rise, Underline, Strikethrough, Size, Scale, Weight, Language, FamilyName, BgColor, FgColor, BgStipple, FgStipple, WrapMode, Direction, Justification, Stretch, Variant, Style, TextPosition, LastDefined,
}
Describes the text attributes supported

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Invalid

Invalid attribute, like bad spelling or grammar.



LeftMargin

The pixel width of the left margin



RightMargin

The pixel width of the right margin



Indent

The number of pixels that the text is indented



Invisible

Either “true” or “false” indicating whether text is visible or not



Editable

Either “true” or “false” indicating whether text is editable or not



PixelsAboveLines

Pixels of blank space to leave above each newline-terminated line.



PixelsBelowLines

Pixels of blank space to leave below each newline-terminated line.



PixelsInsideWrap

Pixels of blank space to leave between wrapped lines inside the same newline-terminated line (paragraph).



BgFullHeight

“true” or “false” whether to make the background color for each character the height of the highest font used on the current line, or the height of the font used for the current character.



Rise

Number of pixels that the characters are risen above the baseline. See also ATK_TEXT_ATTR_TEXT_POSITION.



Underline

“none”, “single”, “double”, “low”, or “error”



Strikethrough

“true” or “false” whether the text is strikethrough



Size

The size of the characters in points. eg: 10



Scale

The scale of the characters. The value is a string representation of a double



Weight

The weight of the characters.



Language

The language used



FamilyName

The font family name



BgColor

The background color. The value is an RGB value of the format “u,u,u



FgColor

The foreground color. The value is an RGB value of the format “u,u,u



BgStipple

“true” if a GdkBitmap is set for stippling the background color.



FgStipple

“true” if a GdkBitmap is set for stippling the foreground color.



WrapMode

The wrap mode of the text, if any. Values are “none”, “char”, “word”, or “word_char”.



Direction

The direction of the text, if set. Values are “none”, “ltr” or “rtl”



Justification

The justification of the text, if set. Values are “left”, “right”, “center” or “fill”



Stretch

The stretch of the text, if set. Values are “ultra_condensed”, “extra_condensed”, “condensed”, “semi_condensed”, “normal”, “semi_expanded”, “expanded”, “extra_expanded” or “ultra_expanded”



Variant

The capitalization variant of the text, if set. Values are “normal” or “small_caps”



Style

The slant style of the text, if set. Values are “normal”, “oblique” or “italic”



TextPosition

The vertical position with respect to the baseline. Values are “baseline”, “super”, or “sub”. Note that a super or sub text attribute refers to position with respect to the baseline of the prior character.



LastDefined

not a valid text attribute, used for finding end of enumeration

Implementations

Source

impl TextAttribute

pub fn for_name(name: &str) -> TextAttribute

pub fn name(self) -> Option<GString>

pub fn value(self, index_: i32) -> Option<GString>