#[non_exhaustive]pub enum TextBoundary {
Char,
WordStart,
WordEnd,
SentenceStart,
SentenceEnd,
LineStart,
LineEnd,
}Expand description
Text boundary types used for specifying boundaries for regions of text.
This enumeration is deprecated since 2.9.4 and should not be used. Use
AtkTextGranularity with atk_text_get_string_at_offset instead.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Char
Boundary is the boundary between characters (including non-printing characters)
WordStart
Boundary is the start (i.e. first character) of a word.
WordEnd
Boundary is the end (i.e. last character) of a word.
SentenceStart
Boundary is the first character in a sentence.
SentenceEnd
Boundary is the last (terminal) character in a sentence; in languages which use “sentence stop” punctuation such as English, the boundary is thus the ‘.’, ‘?’, or similar terminal punctuation character.
LineStart
Boundary is the initial character of the content or a character immediately following a newline, linefeed, or return character.
LineEnd
Boundary is the linefeed, or return character.