#[non_exhaustive]pub enum TextGranularity {
Char,
Word,
Sentence,
Line,
Paragraph,
}Expand description
Text granularity types used for specifying the granularity of the region of text we are interested in.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Char
Granularity is defined by the boundaries between characters (including non-printing characters)
Word
Granularity is defined by the boundaries of a word, starting at the beginning of the current word and finishing at the beginning of the following one, if present.
Sentence
Granularity is defined by the boundaries of a sentence, starting at the beginning of the current sentence and finishing at the beginning of the following one, if present.
Line
Granularity is defined by the boundaries of a line, starting at the beginning of the current line and finishing at the beginning of the following one, if present.
Paragraph
Granularity is defined by the boundaries of a paragraph, starting at the beginning of the current paragraph and finishing at the beginning of the following one, if present.