pub trait TableExtManual:
IsA<Table>
+ Sealed
+ 'static {
// Provided methods
fn selected_columns(&self) -> Vec<i32> { ... }
fn selected_rows(&self) -> Vec<i32> { ... }
}Provided Methods
Sourcefn selected_columns(&self) -> Vec<i32>
fn selected_columns(&self) -> Vec<i32>
Gets the selected columns of the table by initializing **selected with the selected column numbers. This array should be freed by the caller.
selected
a gint** that is to contain the selected columns numbers
Returns
a gint representing the number of selected columns,
or 0 if value does not implement this interface.
Sourcefn selected_rows(&self) -> Vec<i32>
fn selected_rows(&self) -> Vec<i32>
Gets the selected rows of the table by initializing **selected with the selected row numbers. This array should be freed by the caller.
selected
a gint** that is to contain the selected row numbers
Returns
a gint representing the number of selected rows, or zero if value does not implement this interface.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".