Attribute

Struct Attribute 

pub struct Attribute {
    pub name: GString,
    pub value: GString,
}
AtkAttribute is a string name/value pair representing a generic attribute. This can be used to expose additional information from an accessible object as a whole (see atk_object_get_attributes()) or an document (see atk_document_get_attributes()). In the case of text attributes (see atk_text_get_default_attributes()), TextAttribute enum defines all the possible text attribute names. You can use TextAttribute::name() to get the string name from the enum value. See also TextAttribute::for_name() and TextAttribute::value() for more information.

A string name/value pair representing a generic attribute.

Fields

name: GStringvalue: GString