pub struct Component { /* private fields */ }Expand description
The ATK interface provided by UI components which occupy a physical area on the screen. which the user can activate/interact with.
Component should be implemented by most if not all UI elements
with an actual on-screen presence, i.e. components which can be
said to have a screen-coordinate bounding box. Virtually all
widgets will need to have Component implementations provided
for their corresponding Object class. In short, only UI
elements which are not GUI elements will omit this ATK interface.
A possible exception might be textual information with a
transparent background, in which case text glyph bounding box
information is provided by Text.
Signals
bounds-changed
The ’bounds-changed“ signal is emitted when the bposition or size of the component changes.
Implements
Implementations