pub struct EditableText { /* private fields */ }Expand description
The ATK interface implemented by components containing user-editable text content.
EditableText should be implemented by UI components which
contain text which the user can edit, via the Object
corresponding to that component (see Object).
EditableText is a subclass of Text, and as such, an object
which implements EditableText is by definition an Text
implementor as well.
See [ifaceText]
Implements
Implementations
Sourceimpl EditableText
impl EditableText
pub const NONE: Option<&'static EditableText> = None