GObjectAccessible

Struct GObjectAccessible 

pub struct GObjectAccessible { /* private fields */ }
This object class is derived from AtkObject and can be used as a basis implementing accessible objects.

This object class is derived from AtkObject. It can be used as a basis for implementing accessible objects for GObjects which are not derived from GtkWidget. One example of its use is in providing an accessible object for GnomeCanvasItem in the GAIL library.

Implements

GObjectAccessibleExt, AtkObjectExt, glib::ObjectExt

Implementations

Source

impl GObjectAccessible

pub const NONE: Option<&'static GObjectAccessible> = None

pub fn for_object(obj: &impl IsA<Object>) -> Option<Object>

Gets the accessible object for the specified obj.

obj

a glib::Object

Returns

a Object which is the accessible object for the obj