Struct atk::GObjectAccessibleClass
source · [−]#[repr(C)]pub struct GObjectAccessibleClass(_);Trait Implementations
sourceimpl Deref for GObjectAccessibleClass
impl Deref for GObjectAccessibleClass
type Target = <Object as ObjectType>::RustClassType
type Target = <Object as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for GObjectAccessibleClass
impl DerefMut for GObjectAccessibleClass
sourceimpl IsClassFor for GObjectAccessibleClass
impl IsClassFor for GObjectAccessibleClass
type Instance = GObjectAccessible
type Instance = GObjectAccessible
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for GObjectAccessibleClass
impl Sync for GObjectAccessibleClass