pub struct Hyperlink { /* private fields */ }Expand description
An ATK object which encapsulates a link or set of links in a hypertext document.
An ATK object which encapsulates a link or set of links (for instance in the case of client-side image maps) in a hypertext document. It may implement the AtkAction interface. AtkHyperlink may also be used to refer to inline embedded content, since it allows specification of a start and end offset within the host AtkHypertext object.
Properties
end-index
Readable
number-of-anchors
Readable
selected-link
Selected link
Readable
start-index
Readable
Signals
link-activated
The signal link-activated is emitted when a link is activated.
Implements
Implementations