Struct atk::HyperlinkStateFlags
source · [−]pub struct HyperlinkStateFlags { /* private fields */ }Implementations
sourceimpl HyperlinkStateFlags
impl HyperlinkStateFlags
pub const INLINE: HyperlinkStateFlags = _
sourcepub const fn empty() -> HyperlinkStateFlags
pub const fn empty() -> HyperlinkStateFlags
Returns an empty set of flags
sourcepub const fn all() -> HyperlinkStateFlags
pub const fn all() -> HyperlinkStateFlags
Returns the set containing all flags.
sourcepub fn from_bits(bits: u32) -> Option<HyperlinkStateFlags>
pub fn from_bits(bits: u32) -> Option<HyperlinkStateFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> HyperlinkStateFlags
pub const fn from_bits_truncate(bits: u32) -> HyperlinkStateFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> HyperlinkStateFlags
pub const unsafe fn from_bits_unchecked(bits: u32) -> HyperlinkStateFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub const fn intersects(&self, other: HyperlinkStateFlags) -> bool
pub const fn intersects(&self, other: HyperlinkStateFlags) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: HyperlinkStateFlags) -> bool
pub const fn contains(&self, other: HyperlinkStateFlags) -> bool
Returns true all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: HyperlinkStateFlags)
pub fn insert(&mut self, other: HyperlinkStateFlags)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: HyperlinkStateFlags)
pub fn remove(&mut self, other: HyperlinkStateFlags)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: HyperlinkStateFlags)
pub fn toggle(&mut self, other: HyperlinkStateFlags)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: HyperlinkStateFlags, value: bool)
pub fn set(&mut self, other: HyperlinkStateFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.