Struct atk::NoOpObjectFactoryClass
source · [−]#[repr(C)]pub struct NoOpObjectFactoryClass(_);Trait Implementations
sourceimpl Deref for NoOpObjectFactoryClass
impl Deref for NoOpObjectFactoryClass
type Target = <ObjectFactory as ObjectType>::RustClassType
type Target = <ObjectFactory as ObjectType>::RustClassType
The resulting type after dereferencing.
sourceimpl DerefMut for NoOpObjectFactoryClass
impl DerefMut for NoOpObjectFactoryClass
sourceimpl IsClassFor for NoOpObjectFactoryClass
impl IsClassFor for NoOpObjectFactoryClass
type Instance = NoOpObjectFactory
type Instance = NoOpObjectFactory
Corresponding Rust instance type for this class.
sourcefn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref<U>(&self) -> &Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a reference to a parent type’s class.
sourcefn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
fn upcast_ref_mut<U>(&mut self) -> &mut Uwhere
U: IsClassFor,
Self::Instance: IsA<<U as IsClassFor>::Instance>,
<U as IsClassFor>::Instance: ObjectType,
Casts this class to a mutable reference to a parent type’s class.
impl Send for NoOpObjectFactoryClass
impl Sync for NoOpObjectFactoryClass