pub struct Object { /* private fields */ }Expand description
The base object class for the Accessibility Toolkit API.
This class is the primary class for accessibility support via the
Accessibility ToolKit (ATK). Objects which are instances of
Object (or instances of AtkObject-derived types) are queried
for properties which relate basic (and generic) properties of a UI
component such as name and description. Instances of Object
may also be queried as to whether they implement other ATK
interfaces (e.g. Action, Component, etc.), as appropriate
to the role which a given UI component plays in a user interface.
All UI components in an application which provide useful
information or services to the user must provide corresponding
Object instances on request (in GTK+, for instance, usually on
a call to gtk_widget_get_accessible ()), either via ATK support
built into the toolkit for the widget class or ancestor class, or
in the case of custom widgets, if the inherited Object
implementation is insufficient, via instances of a new Object
subclass.
See [classObjectFactory], [classRegistry]. (GTK+ users see also
GtkAccessible).
Properties
accessible-component-layer
Readable
accessible-component-mdi-zorder
Readable
accessible-description
Readable | Writeable
accessible-hypertext-nlinks
Readable
accessible-name
Readable | Writeable
accessible-parent
Readable | Writeable
accessible-role
Readable | Writeable
accessible-table-caption
Table caption.
Readable | Writeable
accessible-table-caption-object
Readable | Writeable
accessible-table-column-description
Accessible table column description.
Readable | Writeable
accessible-table-column-header
Accessible table column header.
Readable | Writeable
accessible-table-row-description
Accessible table row description.
Readable | Writeable
accessible-table-row-header
Accessible table row header.
Readable | Writeable
accessible-table-summary
Readable | Writeable
accessible-value
Numeric value of this object, in case being and AtkValue.
Readable | Writeable
Signals
active-descendant-changed
The “active-descendant-changed” signal is emitted by an object which has the state ATK_STATE_MANAGES_DESCENDANTS when the focus object in the object changes. For instance, a table will emit the signal when the cell in the table which has focus changes.
Detailed
announcement
The “announcement” signal can be emitted to pass an announcement on to be read by a screen reader.
Depcrecated (2.50): Use AtkObject::notification instead.
children-changed
The signal “children-changed” is emitted when a child is added or removed form an object. It supports two details: “add” and “remove”
Detailed
focus-event
The signal “focus-event” is emitted when an object gained or lost focus.
notification
The “notification” signal can be emitted to pass an announcement on to be read by a screen reader.
property-change
The signal “property-change” is emitted when an object’s property
value changes. arg1 contains an AtkPropertyValues with the name
and the new value of the property whose value has changed. Note
that, as with GObject notify, getting this signal does not
guarantee that the value of the property has actually changed; it
may also be emitted when the setter of the property is called to
reinstate the previous value.
Toolkit implementor note: ATK implementors should use
ObjectExt::notify() to emit property-changed
notifications. property-changed is needed by the
implementation of atk_add_global_event_listener() because GObject
notify doesn’t support emission hooks.
Detailed
state-change
The “state-change” signal is emitted when an object’s state changes. The detail value identifies the state type which has changed.
Detailed
visible-data-changed
The “visible-data-changed” signal is emitted when the visual appearance of the object changed.
Implements
Implementations