Text

Struct Text 

pub struct Text { /* private fields */ }
The ATK interface implemented by components with text content.

Text should be implemented by AtkObjects on behalf of widgets that have text content which is either attributed or otherwise non-trivial. AtkObjects whose text content is simple, unattributed, and very brief may expose that content via atk_object_get_name instead; however if the text is editable, multi-line, typically longer than three or four words, attributed, selectable, or if the object already uses the ‘name’ ATK property for other information, the Text interface should be used to expose the text content. In the case of editable text content, EditableText (a subtype of the Text interface) should be implemented instead.

Text provides not only traversal facilities and change notification for text content, but also caret tracking and glyph bounding box calculations. Note that the text strings are exposed as UTF-8, and are therefore potentially multi-byte, and caret-to-byte offset mapping makes no assumptions about the character length; also bounding box glyph-to-offset mapping may be complex for languages which use ligatures.

Signals

text-attributes-changed

The “text-attributes-changed” signal is emitted when the text attributes of the text of an object which implements AtkText changes.

text-caret-moved

The “text-caret-moved” signal is emitted when the caret position of the text of an object which implements AtkText changes.

text-changed

The “text-changed” signal is emitted when the text of the object which implements the AtkText interface changes, This signal will have a detail which is either “insert” or “delete” which identifies whether the text change was an insertion or a deletion.

Detailed

text-insert

The “text-insert” signal is emitted when a new text is inserted. If the signal was not triggered by the user (e.g. typing or pasting text), the “system” detail should be included.

Detailed

text-remove

The “text-remove” signal is emitted when a new text is removed. If the signal was not triggered by the user (e.g. typing or pasting text), the “system” detail should be included.

Detailed

text-selection-changed

The “text-selection-changed” signal is emitted when the selected text of an object which implements AtkText changes.

Implements

TextExt

Implementations

Source

impl Text

pub const NONE: Option<&'static Text> = None