#[non_exhaustive]pub enum RelationType {
Show 22 variants
Null,
ControlledBy,
ControllerFor,
LabelFor,
LabelledBy,
MemberOf,
NodeChildOf,
FlowsTo,
FlowsFrom,
SubwindowOf,
Embeds,
EmbeddedBy,
PopupFor,
ParentWindowOf,
DescribedBy,
DescriptionFor,
NodeParentOf,
Details,
DetailsFor,
ErrorMessage,
ErrorFor,
LastDefined,
}Expand description
Describes the type of the relation
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Null
Not used, represens “no relationship” or an error condition.
ControlledBy
Indicates an object controlled by one or more target objects.
ControllerFor
Indicates an object is an controller for one or more target objects.
LabelFor
Indicates an object is a label for one or more target objects.
LabelledBy
Indicates an object is labelled by one or more target objects.
MemberOf
Indicates an object is a member of a group of one or more target objects.
NodeChildOf
Indicates an object is a cell in a treetable which is displayed because a cell in the same column is expanded and identifies that cell.
FlowsTo
Indicates that the object has content that flows logically to another AtkObject in a sequential way, (for instance text-flow).
FlowsFrom
Indicates that the object has content that flows logically from another AtkObject in a sequential way, (for instance text-flow).
SubwindowOf
Indicates a subwindow attached to a component but otherwise has no connection in the UI heirarchy to that component.
Embeds
Indicates that the object visually embeds another object’s content, i.e. this object’s content flows around another’s content.
EmbeddedBy
Reciprocal of Embeds, indicates that
this object’s content is visualy embedded in another object.
PopupFor
Indicates that an object is a popup for another object.
ParentWindowOf
Indicates that an object is a parent window of another object.
DescribedBy
Reciprocal of DescriptionFor. Indicates that one
or more target objects provide descriptive information about this object. This relation
type is most appropriate for information that is not essential as its presentation may
be user-configurable and/or limited to an on-demand mechanism such as an assistive
technology command. For brief, essential information such as can be found in a widget’s
on-screen label, use LabelledBy. For an on-screen error message, use
ErrorMessage. For lengthy extended descriptive information contained in
an on-screen object, consider using Details as assistive technologies may
provide a means for the user to navigate to objects containing detailed descriptions so
that their content can be more closely reviewed.
DescriptionFor
Reciprocal of DescribedBy. Indicates that this
object provides descriptive information about the target object(s). See also
DetailsFor and ErrorFor.
NodeParentOf
Indicates an object is a cell in a treetable and is expanded to display other cells in the same column.
Details
Reciprocal of DetailsFor. Indicates that this object
has a detailed or extended description, the contents of which can be found in the target
object(s). This relation type is most appropriate for information that is sufficiently
lengthy as to make navigation to the container of that information desirable. For less
verbose information suitable for announcement only, see DescribedBy. If
the detailed information describes an error condition, ErrorFor should be
used instead. Since: ATK-2.26.
DetailsFor
Reciprocal of Details. Indicates that this object
provides a detailed or extended description about the target object(s). See also
DescriptionFor and ErrorFor. Since: ATK-2.26.
ErrorMessage
Reciprocal of ErrorFor. Indicates that this object
has one or more errors, the nature of which is described in the contents of the target
object(s). Objects that have this relation type should also contain StateType::InvalidEntry
in their StateSet. Since: ATK-2.26.
ErrorFor
Reciprocal of ErrorMessage. Indicates that this object
contains an error message describing an invalid condition in the target object(s). Since:
ATK_2.26.
LastDefined
Not used, this value indicates the end of the enumeration.
Implementations