Role

Enum Role 

#[non_exhaustive]
pub enum Role {
Show 129 variants Invalid, AcceleratorLabel, Alert, Animation, Arrow, Calendar, Canvas, CheckBox, CheckMenuItem, ColorChooser, ColumnHeader, ComboBox, DateEditor, DesktopIcon, DesktopFrame, Dial, Dialog, DirectoryPane, DrawingArea, FileChooser, Filler, FontChooser, Frame, GlassPane, HtmlContainer, Icon, Image, InternalFrame, Label, LayeredPane, List, ListItem, Menu, MenuBar, MenuItem, OptionPane, PageTab, PageTabList, Panel, PasswordText, PopupMenu, ProgressBar, PushButton, RadioButton, RadioMenuItem, RootPane, RowHeader, ScrollBar, ScrollPane, Separator, Slider, SplitPane, SpinButton, Statusbar, Table, TableCell, TableColumnHeader, TableRowHeader, TearOffMenuItem, Terminal, Text, ToggleButton, ToolBar, ToolTip, Tree, TreeTable, Unknown, Viewport, Window, Header, Footer, Paragraph, Ruler, Application, Autocomplete, EditBar, Embedded, Entry, Chart, Caption, DocumentFrame, Heading, Page, Section, RedundantObject, Form, Link, InputMethodWindow, TableRow, TreeItem, DocumentSpreadsheet, DocumentPresentation, DocumentText, DocumentWeb, DocumentEmail, Comment, ListBox, Grouping, ImageMap, Notification, InfoBar, LevelBar, TitleBar, BlockQuote, Audio, Video, Definition, Article, Landmark, Log, Marquee, Math, Rating, Timer, DescriptionList, DescriptionTerm, DescriptionValue, Static, MathFraction, MathRoot, Subscript, Superscript, Footnote, ContentDeletion, ContentInsertion, Mark, Suggestion, PushButtonMenu, LastDefined,
}
Describes the role of an object

These are the built-in enumerated roles that UI components can have in ATK. Other roles may be added at runtime, so an AtkRole >= LastDefined is not necessarily an error.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Invalid

Invalid role



AcceleratorLabel

A label which represents an accelerator



Alert

An object which is an alert to the user. Assistive Technologies typically respond to ATK_ROLE_ALERT by reading the entire onscreen contents of containers advertising this role. Should be used for warning dialogs, etc.



Animation

An object which is an animated image



Arrow

An arrow in one of the four cardinal directions



Calendar

An object that displays a calendar and allows the user to select a date



Canvas

An object that can be drawn into and is used to trap events



CheckBox

A choice that can be checked or unchecked and provides a separate indicator for the current state



CheckMenuItem

A menu item with a check box



ColorChooser

A specialized dialog that lets the user choose a color



ColumnHeader

The header for a column of data



ComboBox

A collapsible list of choices the user can select from



DateEditor

An object whose purpose is to allow a user to edit a date



DesktopIcon

An inconifed internal frame within a DESKTOP_PANE



DesktopFrame

A pane that supports internal frames and iconified versions of those internal frames



Dial

An object whose purpose is to allow a user to set a value



Dialog

A top level window with title bar and a border



DirectoryPane

A pane that allows the user to navigate through and select the contents of a directory



DrawingArea

An object used for drawing custom user interface elements



FileChooser

A specialized dialog that lets the user choose a file



Filler

A object that fills up space in a user interface



FontChooser

A specialized dialog that lets the user choose a font



Frame

A top level window with a title bar, border, menubar, etc.



GlassPane

A pane that is guaranteed to be painted on top of all panes beneath it



HtmlContainer

A document container for HTML, whose children represent the document content



Icon

A small fixed size picture, typically used to decorate components



Image

An object whose primary purpose is to display an image



InternalFrame

A frame-like object that is clipped by a desktop pane



Label

An object used to present an icon or short string in an interface



LayeredPane

A specialized pane that allows its children to be drawn in layers, providing a form of stacking order



List

An object that presents a list of objects to the user and allows the user to select one or more of them



ListItem

An object that represents an element of a list



Menu

An object usually found inside a menu bar that contains a list of actions the user can choose from



MenuBar

An object usually drawn at the top of the primary dialog box of an application that contains a list of menus the user can choose from



MenuItem

An object usually contained in a menu that presents an action the user can choose



OptionPane

A specialized pane whose primary use is inside a DIALOG



PageTab

An object that is a child of a page tab list



PageTabList

An object that presents a series of panels (or page tabs), one at a time, through some mechanism provided by the object



Panel

A generic container that is often used to group objects



PasswordText

A text object uses for passwords, or other places where the text content is not shown visibly to the user



PopupMenu

A temporary window that is usually used to offer the user a list of choices, and then hides when the user selects one of those choices



ProgressBar

An object used to indicate how much of a task has been completed



PushButton

An object the user can manipulate to tell the application to do something



RadioButton

A specialized check box that will cause other radio buttons in the same group to become unchecked when this one is checked



RadioMenuItem

A check menu item which belongs to a group. At each instant exactly one of the radio menu items from a group is selected



RootPane

A specialized pane that has a glass pane and a layered pane as its children



RowHeader

The header for a row of data



ScrollBar

An object usually used to allow a user to incrementally view a large amount of data.



ScrollPane

An object that allows a user to incrementally view a large amount of information



Separator

An object usually contained in a menu to provide a visible and logical separation of the contents in a menu



Slider

An object that allows the user to select from a bounded range



SplitPane

A specialized panel that presents two other panels at the same time



SpinButton

An object used to get an integer or floating point number from the user



Statusbar

An object which reports messages of minor importance to the user



Table

An object used to represent information in terms of rows and columns



TableCell

A cell in a table



TableColumnHeader

The header for a column of a table



TableRowHeader

The header for a row of a table



TearOffMenuItem

A menu item used to tear off and reattach its menu



Terminal

An object that represents an accessible terminal. (Since: 0.6)



Text

An interactive widget that supports multiple lines of text and optionally accepts user input, but whose purpose is not to solicit user input. Thus ATK_ROLE_TEXT is appropriate for the text view in a plain text editor but inappropriate for an input field in a dialog box or web form. For widgets whose purpose is to solicit input from the user, see ATK_ROLE_ENTRY and ATK_ROLE_PASSWORD_TEXT. For generic objects which display a brief amount of textual information, see ATK_ROLE_STATIC.



ToggleButton

A specialized push button that can be checked or unchecked, but does not provide a separate indicator for the current state



ToolBar

A bar or palette usually composed of push buttons or toggle buttons



ToolTip

An object that provides information about another object



Tree

An object used to represent hierarchical information to the user



TreeTable

An object capable of expanding and collapsing rows as well as showing multiple columns of data. (Since: 0.7)



Unknown

The object contains some Accessible information, but its role is not known



Viewport

An object usually used in a scroll pane



Window

A top level window with no title or border.



Header

An object that serves as a document header. (Since: 1.1.1)



Footer

An object that serves as a document footer. (Since: 1.1.1)



Paragraph

An object which is contains a paragraph of text content. (Since: 1.1.1)



Ruler

An object which describes margins and tab stops, etc. for text objects which it controls (should have CONTROLLER_FOR relation to such). (Since: 1.1.1)



Application

The object is an application object, which may contain Frame objects or other types of accessibles. The root accessible of any application’s ATK hierarchy should have ATK_ROLE_APPLICATION. (Since: 1.1.4)



Autocomplete

The object is a dialog or list containing items for insertion into an entry widget, for instance a list of words for completion of a text entry. (Since: 1.3)



EditBar

The object is an editable text object in a toolbar. (Since: 1.5)



Embedded

The object is an embedded container within a document or panel. This role is a grouping “hint” indicating that the contained objects share a context. (Since: 1.7.2)



Entry

The object is a component whose textual content may be entered or modified by the user, provided StateType::Editable is present. (Since: 1.11)



Chart

The object is a graphical depiction of quantitative data. It may contain multiple subelements whose attributes and/or description may be queried to obtain both the quantitative data and information about how the data is being presented. The LABELLED_BY relation is particularly important in interpreting objects of this type, as is the accessible-description property. (Since: 1.11)



Caption

The object contains descriptive information, usually textual, about another user interface element such as a table, chart, or image. (Since: 1.11)



DocumentFrame

The object is a visual frame or container which contains a view of document content. Document frames may occur within another Document instance, in which case the second document may be said to be embedded in the containing instance. HTML frames are often ROLE_DOCUMENT_FRAME. Either this object, or a singleton descendant, should implement the Document interface. (Since: 1.11)



Heading

The object serves as a heading for content which follows it in a document. The ‘heading level’ of the heading, if availabe, may be obtained by querying the object’s attributes.



Page

The object is a containing instance which encapsulates a page of information. Page is used in documents and content which support a paginated navigation model. (Since: 1.11)



Section

The object is a containing instance of document content which constitutes a particular ‘logical’ section of the document. The type of content within a section, and the nature of the section division itself, may be obtained by querying the object’s attributes. Sections may be nested. (Since: 1.11)



RedundantObject

The object is redundant with another object in the hierarchy, and is exposed for purely technical reasons. Objects of this role should normally be ignored by clients. (Since: 1.11)



Form

The object is a container for form controls, for instance as part of a web form or user-input form within a document. This role is primarily a tag/convenience for clients when navigating complex documents, it is not expected that ordinary GUI containers will always have ATK_ROLE_FORM. (Since: 1.12.0)

The object is a hypertext anchor, i.e. a “link” in a hypertext document. Such objects are distinct from ‘inline’ content which may also use the Hypertext/Hyperlink interfaces to indicate the range/location within a text object where an inline or embedded object lies. (Since: 1.12.1)



InputMethodWindow

The object is a window or similar viewport which is used to allow composition or input of a ‘complex character’, in other words it is an “input method window.” (Since: 1.12.1)



TableRow

A row in a table. (Since: 2.1.0)



TreeItem

An object that represents an element of a tree. (Since: 2.1.0)



DocumentSpreadsheet

A document frame which contains a spreadsheet. (Since: 2.1.0)



DocumentPresentation

A document frame which contains a presentation or slide content. (Since: 2.1.0)



DocumentText

A document frame which contains textual content, such as found in a word processing application. (Since: 2.1.0)



DocumentWeb

A document frame which contains HTML or other markup suitable for display in a web browser. (Since: 2.1.0)



DocumentEmail

A document frame which contains email content to be displayed or composed either in plain text or HTML. (Since: 2.1.0)



Comment

An object found within a document and designed to present a comment, note, or other annotation. In some cases, this object might not be visible until activated. (Since: 2.1.0)



ListBox

A non-collapsible list of choices the user can select from. (Since: 2.1.0)



Grouping

A group of related widgets. This group typically has a label. (Since: 2.1.0)



ImageMap

An image map object. Usually a graphic with multiple hotspots, where each hotspot can be activated resulting in the loading of another document or section of a document. (Since: 2.1.0)



Notification

A transitory object designed to present a message to the user, typically at the desktop level rather than inside a particular application. (Since: 2.1.0)



InfoBar

An object designed to present a message to the user within an existing window. (Since: 2.1.0)



LevelBar

A bar that serves as a level indicator to, for instance, show the strength of a password or the state of a battery. (Since: 2.7.3)



TitleBar

A bar that serves as the title of a window or a dialog. (Since: 2.12)



BlockQuote

An object which contains a text section that is quoted from another source. (Since: 2.12)



Audio

An object which represents an audio element. (Since: 2.12)



Video

An object which represents a video element. (Since: 2.12)



Definition

A definition of a term or concept. (Since: 2.12)



Article

A section of a page that consists of a composition that forms an independent part of a document, page, or site. Examples: A blog entry, a news story, a forum post. (Since: 2.12)



Landmark

A region of a web page intended as a navigational landmark. This is designed to allow Assistive Technologies to provide quick navigation among key regions within a document. (Since: 2.12)



Log

A text widget or container holding log content, such as chat history and error logs. In this role there is a relationship between the arrival of new items in the log and the reading order. The log contains a meaningful sequence and new information is added only to the end of the log, not at arbitrary points. (Since: 2.12)



Marquee

A container where non-essential information changes frequently. Common usages of marquee include stock tickers and ad banners. The primary difference between a marquee and a log is that logs usually have a meaningful order or sequence of important content changes. (Since: 2.12)



Math

A text widget or container that holds a mathematical expression. (Since: 2.12)



Rating

A widget whose purpose is to display a rating, such as the number of stars associated with a song in a media player. Objects of this role should also implement AtkValue. (Since: 2.12)



Timer

An object containing a numerical counter which indicates an amount of elapsed time from a start point, or the time remaining until an end point. (Since: 2.12)



DescriptionList

An object that represents a list of term-value groups. A term-value group represents a individual description and consist of one or more names (ATK_ROLE_DESCRIPTION_TERM) followed by one or more values (ATK_ROLE_DESCRIPTION_VALUE). For each list, there should not be more than one group with the same term name. (Since: 2.12)



DescriptionTerm

An object that represents a term or phrase with a corresponding definition. (Since: 2.12)



DescriptionValue

An object that represents the description, definition or value of a term. (Since: 2.12)



Static

A generic non-container object whose purpose is to display a brief amount of information to the user and whose role is known by the implementor but lacks semantic value for the user. Examples in which Static is appropriate include the message displayed in a message box and an image used as an alternative means to display text. Static should not be applied to widgets which are traditionally interactive, objects which display a significant amount of content, or any object which has an accessible relation pointing to another object. Implementors should expose the displayed information through the accessible name of the object. If doing so seems inappropriate, it may indicate that a different role should be used. For labels which describe another widget, see Label. For text views, see Text. For generic containers, see Panel. For objects whose role is not known by the implementor, see Unknown. (Since: 2.16)



MathFraction

An object that represents a mathematical fraction. (Since: 2.16)



MathRoot

An object that represents a mathematical expression displayed with a radical. (Since: 2.16)



Subscript

An object that contains text that is displayed as a subscript. (Since: 2.16)



Superscript

An object that contains text that is displayed as a superscript. (Since: 2.16)



Footnote

An object that contains the text of a footnote. (Since: 2.26)



ContentDeletion

Content previously deleted or proposed to be deleted, e.g. in revision history or a content view providing suggestions from reviewers. (Since: 2.34)



ContentInsertion

Content previously inserted or proposed to be inserted, e.g. in revision history or a content view providing suggestions from reviewers. (Since: 2.34)



Mark

A run of content that is marked or highlighted, such as for reference purposes, or to call it out as having a special purpose. If the marked content has an associated section in the document elaborating on the reason for the mark, then RelationType::Details should be used on the mark to point to that associated section. In addition, the reciprocal relation RelationType::DetailsFor should be used on the associated content section to point back to the mark. (Since: 2.36)



Suggestion

A container for content that is called out as a proposed change from the current version of the document, such as by a reviewer of the content. This role should include either ContentDeletion and/or ContentInsertion children, in any order, to indicate what the actual change is. (Since: 2.36)



PushButtonMenu

A specialized push button to open a menu. (Since: 2.46)



LastDefined

not a valid role, used for finding end of the enumeration

Implementations

Source

impl Role

pub fn for_name(name: &str) -> Role

pub fn localized_name(self) -> Option<GString>

pub fn name(self) -> Option<GString>