#[non_exhaustive]pub enum ScrollType {
TopLeft,
BottomRight,
TopEdge,
BottomEdge,
LeftEdge,
RightEdge,
Anywhere,
}v2_30 only.Expand description
Specifies where an object should be placed on the screen when using scroll_to.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
TopLeft
Scroll the object vertically and horizontally to bring its top left corner to the top left corner of the window.
BottomRight
Scroll the object vertically and horizontally to bring its bottom right corner to the bottom right corner of the window.
TopEdge
Scroll the object vertically to bring its top edge to the top edge of the window.
BottomEdge
Scroll the object vertically to bring its bottom edge to the bottom edge of the window.
LeftEdge
Scroll the object vertically and horizontally to bring its left edge to the left edge of the window.
RightEdge
Scroll the object vertically and horizontally to bring its right edge to the right edge of the window.
Anywhere
Scroll the object vertically and horizontally so that as much as possible of the object becomes visible. The exact placement is determined by the application.