AtkActionExt

Trait AtkActionExt 

pub trait AtkActionExt:
    IsA<Action>
    + Sealed
    + 'static {
    // Provided methods
    fn do_action(&self, i: i32) -> bool { ... }
    fn description(&self, i: i32) -> Option<GString> { ... }
    fn keybinding(&self, i: i32) -> Option<GString> { ... }
    fn localized_name(&self, i: i32) -> Option<GString> { ... }
    fn n_actions(&self) -> i32 { ... }
    fn name(&self, i: i32) -> Option<GString> { ... }
    fn set_description(&self, i: i32, desc: &str) -> bool { ... }
}
Trait containing all Action methods.

Implementors

Action, Hyperlink, NoOpObject

Provided Methods

fn do_action(&self, i: i32) -> bool

Perform the specified action on the object.

i

the action index corresponding to the action to be performed

Returns

true if success, false otherwise

fn description(&self, i: i32) -> Option<GString>

Returns a description of the specified action of the object.

i

the action index corresponding to the action to be performed

Returns

a description string, or None if self does not implement this interface.

fn keybinding(&self, i: i32) -> Option<GString>

Gets the keybinding which can be used to activate this action, if one exists. The string returned should contain localized, human-readable, key sequences as they would appear when displayed on screen. It must be in the format “mnemonic;sequence;shortcut”.

  • The mnemonic key activates the object if it is presently enabled onscreen. This typically corresponds to the underlined letter within the widget. Example: “n” in a traditional “New…” menu item or the “a” in “Apply” for a button.
  • The sequence is the full list of keys which invoke the action even if the relevant element is not currently shown on screen. For instance, for a menu item the sequence is the keybindings used to open the parent menus before invoking. The sequence string is colon-delimited. Example: “Alt+F:N” in a traditional “New…” menu item.
  • The shortcut, if it exists, will invoke the same action without showing the component or its enclosing menus or dialogs. Example: “Ctrl+N” in a traditional “New…” menu item.

Example: For a traditional “New…” menu item, the expected return value would be: “N;Alt+F:N;Ctrl+N” for the English locale and “N;Alt+D:N;Strg+N” for the German locale. If, hypothetically, this menu item lacked a mnemonic, it would be represented by “;;Ctrl+N” and “;;Strg+N” respectively.

i

the action index corresponding to the action to be performed

Returns

the keybinding which can be used to activate this action, or None if there is no keybinding for this action.

fn localized_name(&self, i: i32) -> Option<GString>

Returns the localized name of the specified action of the object.

i

the action index corresponding to the action to be performed

Returns

a name string, or None if self does not implement this interface.

fn n_actions(&self) -> i32

Gets the number of accessible actions available on the object. If there are more than one, the first one is considered the “default” action of the object.

Returns

a the number of actions, or 0 if self does not implement this interface.

fn name(&self, i: i32) -> Option<GString>

Returns a non-localized string naming the specified action of the object. This name is generally not descriptive of the end result of the action, but instead names the ‘interaction type’ which the object supports. By convention, the above strings should be used to represent the actions which correspond to the common point-and-click interaction techniques of the same name: i.e. “click”, “press”, “release”, “drag”, “drop”, “popup”, etc. The “popup” action should be used to pop up a context menu for the object, if one exists.

For technical reasons, some toolkits cannot guarantee that the reported action is actually ‘bound’ to a nontrivial user event; i.e. the result of some actions via do_action() may be NIL.

i

the action index corresponding to the action to be performed

Returns

a name string, or None if self does not implement this interface.

fn set_description(&self, i: i32, desc: &str) -> bool

Sets a description of the specified action of the object.

i

the action index corresponding to the action to be performed

desc

the description to be assigned to this action

Returns

a gboolean representing if the description was successfully set;

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors