pub trait AtkMiscExt:
IsA<Misc>
+ Sealed
+ 'static {
// Provided methods
fn threads_enter(&self) { ... }
fn threads_leave(&self) { ... }
}Provided Methods
Sourcefn threads_enter(&self)
fn threads_enter(&self)
Take the thread mutex for the GUI toolkit, if one exists. (This method is implemented by the toolkit ATK implementation layer; for instance, for GTK+, GAIL implements this via GDK_THREADS_ENTER).
Deprecated
Since 2.12.
Sourcefn threads_leave(&self)
fn threads_leave(&self)
Release the thread mutex for the GUI toolkit, if one exists. This method, and atk_misc_threads_enter, are needed in some situations by threaded application code which services ATK requests, since fulfilling ATK requests often requires calling into the GUI toolkit. If a long-running or potentially blocking call takes place inside such a block, it should be bracketed by atk_misc_threads_leave/atk_misc_threads_enter calls. (This method is implemented by the toolkit ATK implementation layer; for instance, for GTK+, GAIL implements this via GDK_THREADS_LEAVE).
Deprecated
Since 2.12.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".