AtkObjectExt

Trait AtkObjectExt 

pub trait AtkObjectExt:
    IsA<Object>
    + Sealed
    + 'static {
Show 70 methods // Provided methods fn add_relationship( &self, relationship: RelationType, target: &impl IsA<Object>, ) -> bool { ... } fn accessible_id(&self) -> Option<GString> { ... } fn description(&self) -> Option<GString> { ... } fn index_in_parent(&self) -> i32 { ... } fn layer(&self) -> Layer { ... } fn mdi_zorder(&self) -> i32 { ... } fn n_accessible_children(&self) -> i32 { ... } fn name(&self) -> Option<GString> { ... } fn object_locale(&self) -> Option<GString> { ... } fn parent(&self) -> Option<Object> { ... } fn role(&self) -> Role { ... } fn notify_state_change(&self, state: State, value: bool) { ... } fn peek_parent(&self) -> Option<Object> { ... } fn ref_accessible_child(&self, i: i32) -> Option<Object> { ... } fn ref_relation_set(&self) -> Option<RelationSet> { ... } fn ref_state_set(&self) -> Option<StateSet> { ... } fn remove_relationship( &self, relationship: RelationType, target: &impl IsA<Object>, ) -> bool { ... } fn set_accessible_id(&self, name: &str) { ... } fn set_description(&self, description: &str) { ... } fn set_name(&self, name: &str) { ... } fn set_parent(&self, parent: &impl IsA<Object>) { ... } fn set_role(&self, role: Role) { ... } fn accessible_component_layer(&self) -> i32 { ... } fn accessible_component_mdi_zorder(&self) -> i32 { ... } fn accessible_description(&self) -> Option<GString> { ... } fn set_accessible_description(&self, accessible_description: Option<&str>) { ... } fn accessible_hypertext_nlinks(&self) -> i32 { ... } fn accessible_name(&self) -> Option<GString> { ... } fn set_accessible_name(&self, accessible_name: Option<&str>) { ... } fn accessible_parent(&self) -> Option<Object> { ... } fn set_accessible_parent<P: IsA<Object>>( &self, accessible_parent: Option<&P>, ) { ... } fn accessible_role(&self) -> Role { ... } fn set_accessible_role(&self, accessible_role: Role) { ... } fn accessible_table_caption(&self) -> Option<GString> { ... } fn set_accessible_table_caption( &self, accessible_table_caption: Option<&str>, ) { ... } fn accessible_table_caption_object(&self) -> Option<Object> { ... } fn set_accessible_table_caption_object<P: IsA<Object>>( &self, accessible_table_caption_object: Option<&P>, ) { ... } fn accessible_table_column_description(&self) -> Option<GString> { ... } fn set_accessible_table_column_description( &self, accessible_table_column_description: Option<&str>, ) { ... } fn accessible_table_column_header(&self) -> Option<Object> { ... } fn set_accessible_table_column_header<P: IsA<Object>>( &self, accessible_table_column_header: Option<&P>, ) { ... } fn accessible_table_row_description(&self) -> Option<GString> { ... } fn set_accessible_table_row_description( &self, accessible_table_row_description: Option<&str>, ) { ... } fn accessible_table_row_header(&self) -> Option<Object> { ... } fn set_accessible_table_row_header<P: IsA<Object>>( &self, accessible_table_row_header: Option<&P>, ) { ... } fn accessible_table_summary(&self) -> Option<Object> { ... } fn set_accessible_table_summary<P: IsA<Object>>( &self, accessible_table_summary: Option<&P>, ) { ... } fn accessible_value(&self) -> f64 { ... } fn set_accessible_value(&self, accessible_value: f64) { ... } fn connect_active_descendant_changed<F: Fn(&Self, &Object) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId { ... } fn connect_announcement<F: Fn(&Self, &str) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_children_changed<F: Fn(&Self, u32, &Object) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId { ... } fn connect_notification<F: Fn(&Self, &str, i32) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_state_change<F: Fn(&Self, &str, bool) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId { ... } fn connect_visible_data_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_component_layer_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_component_mdi_zorder_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_description_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_hypertext_nlinks_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_parent_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_role_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_table_caption_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_table_caption_object_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_table_column_description_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_table_column_header_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_table_row_description_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_table_row_header_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_table_summary_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_accessible_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all Object methods.

Implementors

GObjectAccessible, NoOpObject, Object, Plug, Socket, TableCell, Window

Provided Methods

fn add_relationship( &self, relationship: RelationType, target: &impl IsA<Object>, ) -> bool

Adds a relationship of the specified type with the specified target.

relationship

The RelationType of the relation

target

The Object which is to be the target of the relation.

Returns

TRUE if the relationship is added.

fn accessible_id(&self) -> Option<GString>

Available on crate feature v2_34 only.

Gets the accessible id of the accessible.

Returns

a character string representing the accessible id of the object, or NULL if no such string was set.

fn description(&self) -> Option<GString>

Gets the accessible description of the accessible.

Returns

a character string representing the accessible description of the accessible.

fn index_in_parent(&self) -> i32

Gets the 0-based index of this accessible in its parent; returns -1 if the accessible does not have an accessible parent.

Returns

an integer which is the index of the accessible in its parent

fn layer(&self) -> Layer

Gets the layer of the accessible.

Deprecated

Use atk_component_get_layer instead.

Returns

an Layer which is the layer of the accessible

fn mdi_zorder(&self) -> i32

Gets the zorder of the accessible. The value G_MININT will be returned if the layer of the accessible is not ATK_LAYER_MDI.

Deprecated

Use atk_component_get_mdi_zorder instead.

Returns

a gint which is the zorder of the accessible, i.e. the depth at which the component is shown in relation to other components in the same container.

fn n_accessible_children(&self) -> i32

Gets the number of accessible children of the accessible.

Returns

an integer representing the number of accessible children of the accessible.

fn name(&self) -> Option<GString>

Gets the accessible name of the accessible.

Returns

a character string representing the accessible name of the object.

fn object_locale(&self) -> Option<GString>

Gets a UTF-8 string indicating the POSIX-style LC_MESSAGES locale of self.

Returns

a UTF-8 string indicating the POSIX-style LC_MESSAGES locale of self.

fn parent(&self) -> Option<Object>

Gets the accessible parent of the accessible. By default this is the one assigned with set_parent(), but it is assumed that ATK implementors have ways to get the parent of the object without the need of assigning it manually with set_parent(), and will return it with this method.

If you are only interested on the parent assigned with set_parent(), use peek_parent().

Returns

an Object representing the accessible parent of the accessible

fn role(&self) -> Role

Gets the role of the accessible.

Returns

an Role which is the role of the accessible

fn notify_state_change(&self, state: State, value: bool)

Emits a state-change signal for the specified state.

Note that as a general rule when the state of an existing object changes, emitting a notification is expected.

state

an AtkState whose state is changed

value

a gboolean which indicates whether the state is being set on or off

fn peek_parent(&self) -> Option<Object>

Gets the accessible parent of the accessible, if it has been manually assigned with atk_object_set_parent. Otherwise, this function returns None.

This method is intended as an utility for ATK implementors, and not to be exposed to accessible tools. See parent() for further reference.

Returns

an Object representing the accessible parent of the accessible if assigned

fn ref_accessible_child(&self, i: i32) -> Option<Object>

Gets a reference to the specified accessible child of the object. The accessible children are 0-based so the first accessible child is at index 0, the second at index 1 and so on.

i

a gint representing the position of the child, starting from 0

Returns

an Object representing the specified accessible child of the accessible.

fn ref_relation_set(&self) -> Option<RelationSet>

Gets the RelationSet associated with the object.

Returns

an RelationSet representing the relation set of the object.

fn ref_state_set(&self) -> Option<StateSet>

Gets a reference to the state set of the accessible; the caller must unreference it when it is no longer needed.

Returns

a reference to an StateSet which is the state set of the accessible

fn remove_relationship( &self, relationship: RelationType, target: &impl IsA<Object>, ) -> bool

Removes a relationship of the specified type with the specified target.

relationship

The RelationType of the relation

target

The Object which is the target of the relation to be removed.

Returns

TRUE if the relationship is removed.

fn set_accessible_id(&self, name: &str)

Available on crate feature v2_34 only.

Sets the accessible ID of the accessible. This is not meant to be presented to the user, but to be an ID which is stable over application development. Typically, this is the gtkbuilder ID. Such an ID will be available for instance to identify a given well-known accessible object for tailored screen reading, or for automatic regression testing.

name

a character string to be set as the accessible id

fn set_description(&self, description: &str)

Sets the accessible description of the accessible. You can’t set the description to NULL. This is reserved for the initial value. In this aspect NULL is similar to ATK_ROLE_UNKNOWN. If you want to set the name to a empty value you can use “”.

description

a character string to be set as the accessible description

fn set_name(&self, name: &str)

Sets the accessible name of the accessible. You can’t set the name to NULL. This is reserved for the initial value. In this aspect NULL is similar to ATK_ROLE_UNKNOWN. If you want to set the name to a empty value you can use “”.

name

a character string to be set as the accessible name

fn set_parent(&self, parent: &impl IsA<Object>)

Sets the accessible parent of the accessible. parent can be NULL.

parent

an Object to be set as the accessible parent

fn set_role(&self, role: Role)

Sets the role of the accessible.

role

an Role to be set as the role

fn accessible_component_layer(&self) -> i32

fn accessible_component_mdi_zorder(&self) -> i32

fn accessible_description(&self) -> Option<GString>

fn set_accessible_description(&self, accessible_description: Option<&str>)

fn accessible_name(&self) -> Option<GString>

fn set_accessible_name(&self, accessible_name: Option<&str>)

fn accessible_parent(&self) -> Option<Object>

fn set_accessible_parent<P: IsA<Object>>(&self, accessible_parent: Option<&P>)

fn accessible_role(&self) -> Role

fn set_accessible_role(&self, accessible_role: Role)

fn accessible_table_caption(&self) -> Option<GString>

Table caption.

Deprecated

Since 1.3. Use table-caption-object instead.

fn set_accessible_table_caption(&self, accessible_table_caption: Option<&str>)

Table caption.

Deprecated

Since 1.3. Use table-caption-object instead.

fn accessible_table_caption_object(&self) -> Option<Object>

fn set_accessible_table_caption_object<P: IsA<Object>>( &self, accessible_table_caption_object: Option<&P>, )

fn accessible_table_column_description(&self) -> Option<GString>

Accessible table column description.

Deprecated

Since 2.12. Use TableExt::column_description() and TableExt::set_column_description() instead.

fn set_accessible_table_column_description( &self, accessible_table_column_description: Option<&str>, )

Accessible table column description.

Deprecated

Since 2.12. Use TableExt::column_description() and TableExt::set_column_description() instead.

fn accessible_table_column_header(&self) -> Option<Object>

Accessible table column header.

Deprecated

Since 2.12. Use TableExt::column_header() and TableExt::set_column_header() instead.

fn set_accessible_table_column_header<P: IsA<Object>>( &self, accessible_table_column_header: Option<&P>, )

Accessible table column header.

Deprecated

Since 2.12. Use TableExt::column_header() and TableExt::set_column_header() instead.

fn accessible_table_row_description(&self) -> Option<GString>

Accessible table row description.

Deprecated

Since 2.12. Use TableExt::row_description() and TableExt::set_row_description() instead.

fn set_accessible_table_row_description( &self, accessible_table_row_description: Option<&str>, )

Accessible table row description.

Deprecated

Since 2.12. Use TableExt::row_description() and TableExt::set_row_description() instead.

fn accessible_table_row_header(&self) -> Option<Object>

Accessible table row header.

Deprecated

Since 2.12. Use TableExt::row_header() and TableExt::set_row_header() instead.

fn set_accessible_table_row_header<P: IsA<Object>>( &self, accessible_table_row_header: Option<&P>, )

Accessible table row header.

Deprecated

Since 2.12. Use TableExt::row_header() and TableExt::set_row_header() instead.

fn accessible_table_summary(&self) -> Option<Object>

fn set_accessible_table_summary<P: IsA<Object>>( &self, accessible_table_summary: Option<&P>, )

fn accessible_value(&self) -> f64

Numeric value of this object, in case being and AtkValue.

Deprecated

Since 2.12. Use ValueExt::value_and_text() to get the value, and value-changed signal to be notified on their value changes.

fn set_accessible_value(&self, accessible_value: f64)

Numeric value of this object, in case being and AtkValue.

Deprecated

Since 2.12. Use ValueExt::value_and_text() to get the value, and value-changed signal to be notified on their value changes.

fn connect_active_descendant_changed<F: Fn(&Self, &Object) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId

The “active-descendant-changed” signal is emitted by an object which has the state ATK_STATE_MANAGES_DESCENDANTS when the focus object in the object changes. For instance, a table will emit the signal when the cell in the table which has focus changes.

arg1

the newly focused object.

fn connect_announcement<F: Fn(&Self, &str) + 'static>( &self, f: F, ) -> SignalHandlerId

Available on crate feature v2_46 only.

The “announcement” signal can be emitted to pass an announcement on to be read by a screen reader.

Depcrecated (2.50): Use AtkObject::notification instead.

arg1

the text to be announced.

fn connect_children_changed<F: Fn(&Self, u32, &Object) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId

The signal “children-changed” is emitted when a child is added or removed form an object. It supports two details: “add” and “remove”

arg1

The index of the added or removed child. The value can be -1. This is used if the value is not known by the implementor when the child is added/removed or irrelevant.

arg2

A gpointer to the child AtkObject which was added or removed. If the child was removed, it is possible that it is not available for the implementor. In that case this pointer can be NULL.

fn connect_notification<F: Fn(&Self, &str, i32) + 'static>( &self, f: F, ) -> SignalHandlerId

Available on crate feature v2_50 only.

The “notification” signal can be emitted to pass an announcement on to be read by a screen reader.

arg1

the text to be announced.

arg2

an Live specifying the politeness of the notification. Should be either ATK_LIVE_POLITE or ATK_LIVE_ASSERTIVE.

fn connect_state_change<F: Fn(&Self, &str, bool) + 'static>( &self, detail: Option<&str>, f: F, ) -> SignalHandlerId

The “state-change” signal is emitted when an object’s state changes. The detail value identifies the state type which has changed.

arg1

The name of the state which has changed

arg2

A boolean which indicates whether the state has been set or unset.

fn connect_visible_data_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The “visible-data-changed” signal is emitted when the visual appearance of the object changed.

fn connect_accessible_component_layer_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_component_mdi_zorder_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_description_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_parent_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_role_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_table_caption_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_table_caption_object_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_table_column_description_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_table_column_header_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_table_row_description_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_table_row_header_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_table_summary_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_accessible_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors