pub trait AtkPlugExt:
IsA<Plug>
+ Sealed
+ 'static {
// Provided method
fn id(&self) -> Option<GString> { ... }
}Provided Methods
Sourcefn id(&self) -> Option<GString>
fn id(&self) -> Option<GString>
Gets the unique ID of an Plug object, which can be used to
embed inside of an Socket using AtkSocketExt::embed().
Internally, this calls a class function that should be registered
by the IPC layer (usually at-spi2-atk). The implementor of an
Plug object should call this function (after atk-bridge is
loaded) and pass the value to the process implementing the
Socket, so it could embed the plug.
Returns
the unique ID for the plug
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".