pub trait AtkSocketExt:
IsA<Socket>
+ Sealed
+ 'static {
// Provided methods
fn embed(&self, plug_id: &str) { ... }
fn is_occupied(&self) -> bool { ... }
}Provided Methods
Sourcefn embed(&self, plug_id: &str)
fn embed(&self, plug_id: &str)
Embeds the children of an Plug as the children of the
Socket. The plug may be in the same process or in a different
process.
The class item used by this function should be filled in by the IPC
layer (usually at-spi2-atk). The implementor of the AtkSocket
should call this function and pass the id for the plug as returned
by AtkPlugExt::id(). It is the responsibility of the application
to pass the plug id on to the process implementing the Socket
as needed.
plug_id
the ID of an Plug
Sourcefn is_occupied(&self) -> bool
fn is_occupied(&self) -> bool
Determines whether or not the socket has an embedded plug.
Returns
TRUE if a plug is embedded in the socket
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".