AtkWindowExt

Trait AtkWindowExt 

pub trait AtkWindowExt:
    IsA<Window>
    + Sealed
    + 'static {
    // Provided methods
    fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
    fn connect_create<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
    fn connect_deactivate<F: Fn(&Self) + 'static>(
        &self,
        f: F,
    ) -> SignalHandlerId { ... }
    fn connect_destroy<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
    fn connect_maximize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
    fn connect_minimize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
    fn connect_move<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
    fn connect_resize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
    fn connect_restore<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
}
Trait containing all Window methods.

Implementors

NoOpObject, Window

Provided Methods

fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The signal activate is emitted when a window becomes the active window of the application or session.

fn connect_create<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The signal create is emitted when a new window is created.

fn connect_deactivate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The signal deactivate is emitted when a window is no longer the active window of the application or session.

fn connect_destroy<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The signal destroy is emitted when a window is destroyed.

fn connect_maximize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The signal maximize is emitted when a window is maximized.

fn connect_minimize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The signal minimize is emitted when a window is minimized.

fn connect_move<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The signal move is emitted when a window is moved.

fn connect_resize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The signal resize is emitted when a window is resized.

fn connect_restore<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The signal restore is emitted when a window is restored.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors