pub trait AtkWindowExt:
IsA<Window>
+ Sealed
+ 'static {
// Provided methods
fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_create<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_deactivate<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_destroy<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_maximize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_minimize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_move<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_resize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
fn connect_restore<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The signal activate is emitted when a window
becomes the active window of the application or session.
Sourcefn connect_create<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_create<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The signal create is emitted when a new window
is created.
Sourcefn connect_deactivate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_deactivate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The signal deactivate is emitted when a window is
no longer the active window of the application or session.
Sourcefn connect_destroy<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_destroy<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The signal destroy is emitted when a window is
destroyed.
Sourcefn connect_maximize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_maximize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The signal maximize is emitted when a window
is maximized.
Sourcefn connect_minimize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_minimize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The signal minimize is emitted when a window
is minimized.
Sourcefn connect_move<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_move<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The signal move is emitted when a window
is moved.
Sourcefn connect_resize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_resize<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The signal resize is emitted when a window
is resized.
Sourcefn connect_restore<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_restore<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The signal restore is emitted when a window
is restored.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".