EditableTextExtManual

Trait EditableTextExtManual 

pub trait EditableTextExtManual:
    IsA<EditableText>
    + Sealed
    + 'static {
    // Provided method
    fn insert_text(&self, string: &str, position: i32) -> i32 { ... }
}

Provided Methods

fn insert_text(&self, string: &str, position: i32) -> i32

Insert text at a given position.

string

the text to insert

length

the length of text to insert, in bytes

position

The caller initializes this to the position at which to insert the text. After the call it points at the position after the newly inserted text.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors