pub trait HypertextExt:
IsA<Hypertext>
+ Sealed
+ 'static {
// Provided methods
fn link(&self, link_index: i32) -> Option<Hyperlink> { ... }
fn link_index(&self, char_index: i32) -> i32 { ... }
fn n_links(&self) -> i32 { ... }
fn connect_link_selected<F: Fn(&Self, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn link_index(&self, char_index: i32) -> i32
fn link_index(&self, char_index: i32) -> i32
Sourcefn n_links(&self) -> i32
fn n_links(&self) -> i32
Gets the number of links within this hypertext document.
Returns
the number of links within this hypertext document
Sourcefn connect_link_selected<F: Fn(&Self, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_link_selected<F: Fn(&Self, i32) + 'static>( &self, f: F, ) -> SignalHandlerId
The “link-selected” signal is emitted by an AtkHyperText object when one of the hyperlinks associated with the object is selected.
arg1
the index of the hyperlink which is selected
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".