ObjectFactoryExt

Trait ObjectFactoryExt 

pub trait ObjectFactoryExt:
    IsA<ObjectFactory>
    + Sealed
    + 'static {
    // Provided methods
    fn create_accessible(&self, obj: &impl IsA<Object>) -> Option<Object> { ... }
    fn accessible_type(&self) -> Type { ... }
    fn invalidate(&self) { ... }
}
Trait containing all ObjectFactory methods.

Implementors

NoOpObjectFactory, ObjectFactory

Provided Methods

fn create_accessible(&self, obj: &impl IsA<Object>) -> Option<Object>

Provides an Object that implements an accessibility interface on behalf of obj

obj

a glib::Object

Returns

an Object that implements an accessibility interface on behalf of obj

fn accessible_type(&self) -> Type

Gets the GType of the accessible which is created by the factory.

Returns

the type of the accessible which is created by the self. The value G_TYPE_INVALID is returned if no type if found.

fn invalidate(&self)

Inform self that it is no longer being used to create accessibles. When called, self may need to inform AtkObjects which it has created that they need to be re-instantiated. Note: primarily used for runtime replacement of AtkObjectFactorys in object registries.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors