pub trait ObjectFactoryExt:
IsA<ObjectFactory>
+ Sealed
+ 'static {
// Provided methods
fn create_accessible(&self, obj: &impl IsA<Object>) -> Option<Object> { ... }
fn accessible_type(&self) -> Type { ... }
fn invalidate(&self) { ... }
}Expand description
Provided Methods
Sourcefn create_accessible(&self, obj: &impl IsA<Object>) -> Option<Object>
fn create_accessible(&self, obj: &impl IsA<Object>) -> Option<Object>
Sourcefn accessible_type(&self) -> Type
fn accessible_type(&self) -> Type
Gets the GType of the accessible which is created by the factory.
Returns
the type of the accessible which is created by the self.
The value G_TYPE_INVALID is returned if no type if found.
Sourcefn invalidate(&self)
fn invalidate(&self)
Inform self that it is no longer being used to create
accessibles. When called, self may need to inform
AtkObjects which it has created that they need to be re-instantiated.
Note: primarily used for runtime replacement of AtkObjectFactorys
in object registries.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".