RegistryExt

Trait RegistryExt 

pub trait RegistryExt:
    IsA<Registry>
    + Sealed
    + 'static {
    // Provided methods
    fn factory(&self, type_: Type) -> Option<ObjectFactory> { ... }
    fn factory_type(&self, type_: Type) -> Type { ... }
    fn set_factory_type(&self, type_: Type, factory_type: Type) { ... }
}
Trait containing all Registry methods.

Implementors

Registry

Provided Methods

fn factory(&self, type_: Type) -> Option<ObjectFactory>

Gets an ObjectFactory appropriate for creating AtkObjects appropriate for type_.

type_

a GType with which to look up the associated ObjectFactory

Returns

an ObjectFactory appropriate for creating AtkObjects appropriate for type_.

fn factory_type(&self, type_: Type) -> Type

Provides a GType indicating the ObjectFactory subclass associated with type_.

type_

a GType with which to look up the associated ObjectFactory subclass

Returns

a GType associated with type type_

fn set_factory_type(&self, type_: Type, factory_type: Type)

Associate an ObjectFactory subclass with a GType. Note: The associated factory_type will thereafter be responsible for the creation of new Object implementations for instances appropriate for type_.

type_

an Object type

factory_type

an ObjectFactory type to associate with type_. Must implement AtkObject appropriate for type_.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors