StreamableContentExt

Trait StreamableContentExt 

pub trait StreamableContentExt:
    IsA<StreamableContent>
    + Sealed
    + 'static {
    // Provided methods
    fn mime_type(&self, i: i32) -> Option<GString> { ... }
    fn n_mime_types(&self) -> i32 { ... }
    fn uri(&self, mime_type: &str) -> Option<GString> { ... }
}
Trait containing all StreamableContent methods.

Implementors

StreamableContent

Provided Methods

fn mime_type(&self, i: i32) -> Option<GString>

Gets the character string of the specified mime type. The first mime type is at position 0, the second at position 1, and so on.

i

a gint representing the position of the mime type starting from 0

Returns

a gchar* representing the specified mime type; the caller should not free the character string.

fn n_mime_types(&self) -> i32

Gets the number of mime types supported by this object.

Returns

a gint which is the number of mime types supported by the object.

fn uri(&self, mime_type: &str) -> Option<GString>

Get a string representing a URI in IETF standard format (see http://www.ietf.org/rfc/rfc2396.txt) from which the object’s content may be streamed in the specified mime-type, if one is available. If mime_type is NULL, the URI for the default (and possibly only) mime-type is returned.

Note that it is possible for get_uri to return NULL but for get_stream to work nonetheless, since not all GIOChannels connect to URIs.

mime_type

a gchar* representing the mime type, or NULL to request a URI for the default mime type.

Returns

Returns a string representing a URI, or None if no corresponding URI can be constructed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors