TableCellExt

Trait TableCellExt 

pub trait TableCellExt:
    IsA<TableCell>
    + Sealed
    + 'static {
    // Provided methods
    fn column_header_cells(&self) -> Vec<Object> { ... }
    fn column_span(&self) -> i32 { ... }
    fn position(&self) -> Option<(i32, i32)> { ... }
    fn row_column_span(&self) -> Option<(i32, i32, i32, i32)> { ... }
    fn row_header_cells(&self) -> Vec<Object> { ... }
    fn row_span(&self) -> i32 { ... }
    fn table(&self) -> Option<Object> { ... }
}
Trait containing all TableCell methods.

Implementors

NoOpObject, TableCell

Provided Methods

fn column_header_cells(&self) -> Vec<Object>

Returns the column headers as an array of cell accessibles.

Returns

a GPtrArray of AtkObjects representing the column header cells.

fn column_span(&self) -> i32

Returns the number of columns occupied by this cell accessible.

Returns

a gint representing the number of columns occupied by this cell, or 0 if the cell does not implement this method.

fn position(&self) -> Option<(i32, i32)>

Retrieves the tabular position of this cell.

Returns

TRUE if successful; FALSE otherwise.

row

the row of the given cell.

column

the column of the given cell.

fn row_column_span(&self) -> Option<(i32, i32, i32, i32)>

Gets the row and column indexes and span of this cell accessible.

Note: If the object does not implement this function, then, by default, atk will implement this function by calling get_row_span and get_column_span on the object.

Returns

TRUE if successful; FALSE otherwise.

row

the row index of the given cell.

column

the column index of the given cell.

row_span

the number of rows occupied by this cell.

column_span

the number of columns occupied by this cell.

fn row_header_cells(&self) -> Vec<Object>

Returns the row headers as an array of cell accessibles.

Returns

a GPtrArray of AtkObjects representing the row header cells.

fn row_span(&self) -> i32

Returns the number of rows occupied by this cell accessible.

Returns

a gint representing the number of rows occupied by this cell, or 0 if the cell does not implement this method.

fn table(&self) -> Option<Object>

Returns a reference to the accessible of the containing table.

Returns

the atk object for the containing table.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors