TableExt

Trait TableExt 

pub trait TableExt:
    IsA<Table>
    + Sealed
    + 'static {
Show 34 methods // Provided methods fn add_column_selection(&self, column: i32) -> bool { ... } fn add_row_selection(&self, row: i32) -> bool { ... } fn caption(&self) -> Option<Object> { ... } fn column_at_index(&self, index_: i32) -> i32 { ... } fn column_description(&self, column: i32) -> Option<GString> { ... } fn column_extent_at(&self, row: i32, column: i32) -> i32 { ... } fn column_header(&self, column: i32) -> Option<Object> { ... } fn index_at(&self, row: i32, column: i32) -> i32 { ... } fn n_columns(&self) -> i32 { ... } fn n_rows(&self) -> i32 { ... } fn row_at_index(&self, index_: i32) -> i32 { ... } fn row_description(&self, row: i32) -> Option<GString> { ... } fn row_extent_at(&self, row: i32, column: i32) -> i32 { ... } fn row_header(&self, row: i32) -> Option<Object> { ... } fn summary(&self) -> Option<Object> { ... } fn is_column_selected(&self, column: i32) -> bool { ... } fn is_row_selected(&self, row: i32) -> bool { ... } fn is_selected(&self, row: i32, column: i32) -> bool { ... } fn ref_at(&self, row: i32, column: i32) -> Option<Object> { ... } fn remove_column_selection(&self, column: i32) -> bool { ... } fn remove_row_selection(&self, row: i32) -> bool { ... } fn set_caption(&self, caption: &impl IsA<Object>) { ... } fn set_column_description(&self, column: i32, description: &str) { ... } fn set_column_header(&self, column: i32, header: &impl IsA<Object>) { ... } fn set_row_description(&self, row: i32, description: &str) { ... } fn set_row_header(&self, row: i32, header: &impl IsA<Object>) { ... } fn set_summary(&self, accessible: &impl IsA<Object>) { ... } fn connect_column_deleted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_column_inserted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_column_reordered<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_model_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_row_deleted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_row_inserted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_row_reordered<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all Table methods.

Implementors

NoOpObject, Table

Provided Methods

fn add_column_selection(&self, column: i32) -> bool

Adds the specified column to the selection.

column

a gint representing a column in self

Returns

a gboolean representing if the column was successfully added to the selection, or 0 if value does not implement this interface.

fn add_row_selection(&self, row: i32) -> bool

Adds the specified row to the selection.

row

a gint representing a row in self

Returns

a gboolean representing if row was successfully added to selection, or 0 if value does not implement this interface.

fn caption(&self) -> Option<Object>

Gets the caption for the self.

Returns

a AtkObject* representing the table caption, or None if value does not implement this interface.

fn column_at_index(&self, index_: i32) -> i32

Gets a gint representing the column at the specified index_.

Deprecated

Since 2.12.

index_

a gint representing an index in self

Returns

a gint representing the column at the specified index, or -1 if the table does not implement this method.

fn column_description(&self, column: i32) -> Option<GString>

Gets the description text of the specified column in the table

column

a gint representing a column in self

Returns

a gchar* representing the column description, or None if value does not implement this interface.

fn column_extent_at(&self, row: i32, column: i32) -> i32

Gets the number of columns occupied by the accessible object at the specified row and column in the self.

row

a gint representing a row in self

column

a gint representing a column in self

Returns

a gint representing the column extent at specified position, or 0 if value does not implement this interface.

fn column_header(&self, column: i32) -> Option<Object>

Gets the column header of a specified column in an accessible table.

column

a gint representing a column in the table

Returns

a AtkObject* representing the specified column header, or None if value does not implement this interface.

fn index_at(&self, row: i32, column: i32) -> i32

Gets a gint representing the index at the specified row and column.

Deprecated

Since 2.12. Use ref_at() in order to get the accessible that represents the cell at (row, column)

row

a gint representing a row in self

column

a gint representing a column in self

Returns

a gint representing the index at specified position. The value -1 is returned if the object at row,column is not a child of table or table does not implement this interface.

fn n_columns(&self) -> i32

Gets the number of columns in the table.

Returns

a gint representing the number of columns, or 0 if value does not implement this interface.

fn n_rows(&self) -> i32

Gets the number of rows in the table.

Returns

a gint representing the number of rows, or 0 if value does not implement this interface.

fn row_at_index(&self, index_: i32) -> i32

Gets a gint representing the row at the specified index_.

Deprecated

since 2.12.

index_

a gint representing an index in self

Returns

a gint representing the row at the specified index, or -1 if the table does not implement this method.

fn row_description(&self, row: i32) -> Option<GString>

Gets the description text of the specified row in the table

row

a gint representing a row in self

Returns

a gchar* representing the row description, or None if value does not implement this interface.

fn row_extent_at(&self, row: i32, column: i32) -> i32

Gets the number of rows occupied by the accessible object at a specified row and column in the self.

row

a gint representing a row in self

column

a gint representing a column in self

Returns

a gint representing the row extent at specified position, or 0 if value does not implement this interface.

fn row_header(&self, row: i32) -> Option<Object>

Gets the row header of a specified row in an accessible table.

row

a gint representing a row in the table

Returns

a AtkObject* representing the specified row header, or None if value does not implement this interface.

fn summary(&self) -> Option<Object>

Gets the summary description of the table.

Returns

a AtkObject* representing a summary description of the table, or zero if value does not implement this interface.

fn is_column_selected(&self, column: i32) -> bool

Gets a boolean value indicating whether the specified column is selected

column

a gint representing a column in self

Returns

a gboolean representing if the column is selected, or 0 if value does not implement this interface.

fn is_row_selected(&self, row: i32) -> bool

Gets a boolean value indicating whether the specified row is selected

row

a gint representing a row in self

Returns

a gboolean representing if the row is selected, or 0 if value does not implement this interface.

fn is_selected(&self, row: i32, column: i32) -> bool

Gets a boolean value indicating whether the accessible object at the specified row and column is selected

row

a gint representing a row in self

column

a gint representing a column in self

Returns

a gboolean representing if the cell is selected, or 0 if value does not implement this interface.

fn ref_at(&self, row: i32, column: i32) -> Option<Object>

Get a reference to the table cell at row, column. This cell should implement the interface TableCell

row

a gint representing a row in self

column

a gint representing a column in self

Returns

an Object representing the referred to accessible

fn remove_column_selection(&self, column: i32) -> bool

Adds the specified column to the selection.

column

a gint representing a column in self

Returns

a gboolean representing if the column was successfully removed from the selection, or 0 if value does not implement this interface.

fn remove_row_selection(&self, row: i32) -> bool

Removes the specified row from the selection.

row

a gint representing a row in self

Returns

a gboolean representing if the row was successfully removed from the selection, or 0 if value does not implement this interface.

fn set_caption(&self, caption: &impl IsA<Object>)

Sets the caption for the table.

caption

a Object representing the caption to set for self

fn set_column_description(&self, column: i32, description: &str)

Sets the description text for the specified column of the self.

column

a gint representing a column in self

description

a gchar representing the description text to set for the specified column of the self

fn set_column_header(&self, column: i32, header: &impl IsA<Object>)

Sets the specified column header to header.

column

a gint representing a column in self

an Table

fn set_row_description(&self, row: i32, description: &str)

Sets the description text for the specified row of self.

row

a gint representing a row in self

description

a gchar representing the description text to set for the specified row of self

fn set_row_header(&self, row: i32, header: &impl IsA<Object>)

Sets the specified row header to header.

row

a gint representing a row in self

header

an Table

fn set_summary(&self, accessible: &impl IsA<Object>)

Sets the summary description of the table.

accessible

an Object representing the summary description to set for self

fn connect_column_deleted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId

The “column-deleted” signal is emitted by an object which implements the AtkTable interface when a column is deleted.

arg1

The index of the first column deleted.

arg2

The number of columns deleted.

fn connect_column_inserted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId

The “column-inserted” signal is emitted by an object which implements the AtkTable interface when a column is inserted.

arg1

The index of the column inserted.

arg2

The number of colums inserted.

fn connect_column_reordered<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

The “column-reordered” signal is emitted by an object which implements the AtkTable interface when the columns are reordered.

fn connect_model_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The “model-changed” signal is emitted by an object which implements the AtkTable interface when the model displayed by the table changes.

fn connect_row_deleted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId

The “row-deleted” signal is emitted by an object which implements the AtkTable interface when a row is deleted.

arg1

The index of the first row deleted.

arg2

The number of rows deleted.

fn connect_row_inserted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId

The “row-inserted” signal is emitted by an object which implements the AtkTable interface when a row is inserted.

arg1

The index of the first row inserted.

arg2

The number of rows inserted.

fn connect_row_reordered<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

The “row-reordered” signal is emitted by an object which implements the AtkTable interface when the rows are reordered.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<O: IsA<Table>> TableExt for O