pub trait TableExt:
IsA<Table>
+ Sealed
+ 'static {
Show 34 methods
// Provided methods
fn add_column_selection(&self, column: i32) -> bool { ... }
fn add_row_selection(&self, row: i32) -> bool { ... }
fn caption(&self) -> Option<Object> { ... }
fn column_at_index(&self, index_: i32) -> i32 { ... }
fn column_description(&self, column: i32) -> Option<GString> { ... }
fn column_extent_at(&self, row: i32, column: i32) -> i32 { ... }
fn column_header(&self, column: i32) -> Option<Object> { ... }
fn index_at(&self, row: i32, column: i32) -> i32 { ... }
fn n_columns(&self) -> i32 { ... }
fn n_rows(&self) -> i32 { ... }
fn row_at_index(&self, index_: i32) -> i32 { ... }
fn row_description(&self, row: i32) -> Option<GString> { ... }
fn row_extent_at(&self, row: i32, column: i32) -> i32 { ... }
fn row_header(&self, row: i32) -> Option<Object> { ... }
fn summary(&self) -> Option<Object> { ... }
fn is_column_selected(&self, column: i32) -> bool { ... }
fn is_row_selected(&self, row: i32) -> bool { ... }
fn is_selected(&self, row: i32, column: i32) -> bool { ... }
fn ref_at(&self, row: i32, column: i32) -> Option<Object> { ... }
fn remove_column_selection(&self, column: i32) -> bool { ... }
fn remove_row_selection(&self, row: i32) -> bool { ... }
fn set_caption(&self, caption: &impl IsA<Object>) { ... }
fn set_column_description(&self, column: i32, description: &str) { ... }
fn set_column_header(&self, column: i32, header: &impl IsA<Object>) { ... }
fn set_row_description(&self, row: i32, description: &str) { ... }
fn set_row_header(&self, row: i32, header: &impl IsA<Object>) { ... }
fn set_summary(&self, accessible: &impl IsA<Object>) { ... }
fn connect_column_deleted<F: Fn(&Self, i32, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_column_inserted<F: Fn(&Self, i32, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_column_reordered<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_model_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_row_deleted<F: Fn(&Self, i32, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_row_inserted<F: Fn(&Self, i32, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_row_reordered<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn add_column_selection(&self, column: i32) -> bool
fn add_column_selection(&self, column: i32) -> bool
Sourcefn add_row_selection(&self, row: i32) -> bool
fn add_row_selection(&self, row: i32) -> bool
Sourcefn column_at_index(&self, index_: i32) -> i32
fn column_at_index(&self, index_: i32) -> i32
Sourcefn column_description(&self, column: i32) -> Option<GString>
fn column_description(&self, column: i32) -> Option<GString>
Sourcefn column_extent_at(&self, row: i32, column: i32) -> i32
fn column_extent_at(&self, row: i32, column: i32) -> i32
Gets the number of columns occupied by the accessible object
at the specified row and column in the self.
row
a gint representing a row in self
column
a gint representing a column in self
Returns
a gint representing the column extent at specified position, or 0 if value does not implement this interface.
Sourcefn column_header(&self, column: i32) -> Option<Object>
fn column_header(&self, column: i32) -> Option<Object>
Sourcefn index_at(&self, row: i32, column: i32) -> i32
fn index_at(&self, row: i32, column: i32) -> i32
Gets a gint representing the index at the specified row and
column.
Deprecated
Since 2.12. Use ref_at() in order to get the
accessible that represents the cell at (row, column)
row
a gint representing a row in self
column
a gint representing a column in self
Returns
a gint representing the index at specified position.
The value -1 is returned if the object at row,column is not a child
of table or table does not implement this interface.
Sourcefn n_columns(&self) -> i32
fn n_columns(&self) -> i32
Gets the number of columns in the table.
Returns
a gint representing the number of columns, or 0 if value does not implement this interface.
Sourcefn n_rows(&self) -> i32
fn n_rows(&self) -> i32
Gets the number of rows in the table.
Returns
a gint representing the number of rows, or 0 if value does not implement this interface.
Sourcefn row_at_index(&self, index_: i32) -> i32
fn row_at_index(&self, index_: i32) -> i32
Sourcefn row_description(&self, row: i32) -> Option<GString>
fn row_description(&self, row: i32) -> Option<GString>
Sourcefn row_extent_at(&self, row: i32, column: i32) -> i32
fn row_extent_at(&self, row: i32, column: i32) -> i32
Gets the number of rows occupied by the accessible object
at a specified row and column in the self.
row
a gint representing a row in self
column
a gint representing a column in self
Returns
a gint representing the row extent at specified position, or 0 if value does not implement this interface.
Sourcefn row_header(&self, row: i32) -> Option<Object>
fn row_header(&self, row: i32) -> Option<Object>
Sourcefn summary(&self) -> Option<Object>
fn summary(&self) -> Option<Object>
Gets the summary description of the table.
Returns
a AtkObject* representing a summary description of the table, or zero if value does not implement this interface.
Sourcefn is_column_selected(&self, column: i32) -> bool
fn is_column_selected(&self, column: i32) -> bool
Sourcefn is_row_selected(&self, row: i32) -> bool
fn is_row_selected(&self, row: i32) -> bool
Sourcefn is_selected(&self, row: i32, column: i32) -> bool
fn is_selected(&self, row: i32, column: i32) -> bool
Sourcefn remove_column_selection(&self, column: i32) -> bool
fn remove_column_selection(&self, column: i32) -> bool
Sourcefn remove_row_selection(&self, row: i32) -> bool
fn remove_row_selection(&self, row: i32) -> bool
Sourcefn set_caption(&self, caption: &impl IsA<Object>)
fn set_caption(&self, caption: &impl IsA<Object>)
Sourcefn set_column_description(&self, column: i32, description: &str)
fn set_column_description(&self, column: i32, description: &str)
Sourcefn set_column_header(&self, column: i32, header: &impl IsA<Object>)
fn set_column_header(&self, column: i32, header: &impl IsA<Object>)
Sourcefn set_row_description(&self, row: i32, description: &str)
fn set_row_description(&self, row: i32, description: &str)
Sourcefn set_row_header(&self, row: i32, header: &impl IsA<Object>)
fn set_row_header(&self, row: i32, header: &impl IsA<Object>)
Sourcefn set_summary(&self, accessible: &impl IsA<Object>)
fn set_summary(&self, accessible: &impl IsA<Object>)
Sourcefn connect_column_deleted<F: Fn(&Self, i32, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_column_deleted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcefn connect_column_inserted<F: Fn(&Self, i32, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_column_inserted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcefn connect_column_reordered<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_column_reordered<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
The “column-reordered” signal is emitted by an object which implements the AtkTable interface when the columns are reordered.
Sourcefn connect_model_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_model_changed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The “model-changed” signal is emitted by an object which implements the AtkTable interface when the model displayed by the table changes.
Sourcefn connect_row_deleted<F: Fn(&Self, i32, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_row_deleted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcefn connect_row_inserted<F: Fn(&Self, i32, i32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
fn connect_row_inserted<F: Fn(&Self, i32, i32) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcefn connect_row_reordered<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_row_reordered<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
The “row-reordered” signal is emitted by an object which implements the AtkTable interface when the rows are reordered.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".