pub struct NoOpObject { /* private fields */ }Expand description
An AtkObject which purports to implement all ATK interfaces.
An AtkNoOpObject is an AtkObject which purports to implement all ATK interfaces. It is the type of AtkObject which is created if an accessible object is requested for an object type for which no factory type is specified.
Implements
AtkObjectExt, glib::ObjectExt, AtkActionExt, ComponentExt, DocumentExt, EditableTextExt, HypertextExt, AtkImageExt, SelectionExt, TableExt, TableCellExt, TextExt, ValueExt, AtkWindowExt, EditableTextExtManual, TableExtManual
Implementations