pub struct RelationSet { /* private fields */ }Expand description
A set of AtkRelations, normally the set of AtkRelations which an AtkObject has.
The AtkRelationSet held by an object establishes its relationships with objects beyond the normal “parent/child” hierarchical relationships that all user interface objects have. AtkRelationSets establish whether objects are labelled or controlled by other components, share group membership with other components (for instance within a radio-button group), or share content which “flows” between them, among other types of possible relationships.
Implements
Implementations
Sourceimpl RelationSet
impl RelationSet
pub const NONE: Option<&'static RelationSet> = None
Sourcepub fn new() -> RelationSet
pub fn new() -> RelationSet