Table

Struct Table 

pub struct Table { /* private fields */ }
The ATK interface implemented for UI components which contain tabular or row/column information.

Table should be implemented by components which present elements ordered via rows and columns. It may also be used to present tree-structured information if the nodes of the trees can be said to contain multiple “columns”. Individual elements of an Table are typically referred to as “cells”. Those cells should implement the interface TableCell, but Atk doesn’t require them to be direct children of the current Table. They can be grand-children, grand-grand-children etc. Table provides the API needed to get a individual cell based on the row and column numbers.

Children of Table are frequently “lightweight” objects, that is, they may not have backing widgets in the host UI toolkit. They are therefore often transient.

Since tables are often very complex, Table includes provision for offering simplified summary information, as well as row and column headers and captions. Headers and captions are AtkObjects which may implement other interfaces (Text, Image, etc.) as appropriate. Table summaries may themselves be (simplified) AtkTables, etc.

Note for implementors: in the past, Table required that all the cells should be direct children of Table, and provided some index based methods to request the cells. The practice showed that that forcing made Table implementation complex, and hard to expose other kind of children, like rows or captions. Right now, index-based methods are deprecated.

Signals

column-deleted

The “column-deleted” signal is emitted by an object which implements the AtkTable interface when a column is deleted.

column-inserted

The “column-inserted” signal is emitted by an object which implements the AtkTable interface when a column is inserted.

column-reordered

The “column-reordered” signal is emitted by an object which implements the AtkTable interface when the columns are reordered.

model-changed

The “model-changed” signal is emitted by an object which implements the AtkTable interface when the model displayed by the table changes.

row-deleted

The “row-deleted” signal is emitted by an object which implements the AtkTable interface when a row is deleted.

row-inserted

The “row-inserted” signal is emitted by an object which implements the AtkTable interface when a row is inserted.

row-reordered

The “row-reordered” signal is emitted by an object which implements the AtkTable interface when the rows are reordered.

Implements

TableExt, TableExtManual

Implementations

Source

impl Table

pub const NONE: Option<&'static Table> = None