pub struct Value { /* private fields */ }Expand description
The ATK interface implemented by valuators and components which display or select a value from a bounded range of values.
Value should be implemented for components which either display
a value from a bounded range, or which allow the user to specify a
value from a bounded range, or both. For instance, most sliders and
range controls, as well as dials, should have Object
representations which implement Value on the component’s
behalf. AtKValues may be read-only, in which case attempts to
alter the value return would fail.
<example>
<title>Password strength</title>
A password strength meter whose value changes as the user types
their new password. Red is used for values less than 4.0, yellow
for values between 4.0 and 7.0, and green for values greater than
7.0. In this instance, value text should be provided by the
implementor. Appropriate value text would be “weak”, “acceptable,”
and “strong” respectively.
</example>
A level bar whose value changes to reflect the battery charge. The color remains the same regardless of the charge and there is no on-screen text reflecting the fullness of the battery. In this case, because the position within the bar is the only indication the user has of the current charge, value text should not be provided by the implementor.
<para>
Value should NOT be implemented for widgets whose displayed
value is not reflective of a meaningful amount. For instance, a
progress pulse indicator whose value alternates between 0.0 and 1.0
to indicate that some process is still taking place should not
implement Value because the current value does not reflect
progress towards completion.
</para>
</refsect2>
</refsect1>
<itemizedlist>
<listitem>ATK_VALUE_VERY_WEAK</listitem>
<listitem>ATK_VALUE_WEAK</listitem>
<listitem>ATK_VALUE_ACCEPTABLE</listitem>
<listitem>ATK_VALUE_STRONG</listitem>
<listitem>ATK_VALUE_VERY_STRONG</listitem>
<listitem>ATK_VALUE_VERY_LOW</listitem>
<listitem>ATK_VALUE_LOW</listitem>
<listitem>ATK_VALUE_MEDIUM</listitem>
<listitem>ATK_VALUE_HIGH</listitem>
<listitem>ATK_VALUE_VERY_HIGH</listitem>
<listitem>ATK_VALUE_VERY_BAD</listitem>
<listitem>ATK_VALUE_BAD</listitem>
<listitem>ATK_VALUE_GOOD</listitem>
<listitem>ATK_VALUE_VERY_GOOD</listitem>
<listitem>ATK_VALUE_BEST</listitem>
<listitem>ATK_VALUE_SUBSUBOPTIMAL</listitem>
<listitem>ATK_VALUE_SUBOPTIMAL</listitem>
<listitem>ATK_VALUE_OPTIMAL</listitem>
</itemizedlist>
<para>
Proposals for additional constants, along with their use cases,
should be submitted to the GNOME Accessibility Team.
</para>
</refsect1>
Signals
value-changed
The ‘value-changed’ signal is emitted when the current value
that represent the object changes. value is the numerical
representation of this new value. text is the human
readable text alternative of value, and can be NULL if it is
not available. Note that if there is a textual description
associated with the new numeric value, that description
should be included regardless of whether or not it has also
changed.
Example: a password meter whose value changes as the user types their new password. Appropiate value text would be “weak”, “acceptable” and “strong”.
Implements
Implementations