pub struct Window { /* private fields */ }Expand description
The ATK Interface provided by UI components that represent a top-level window.
Window should be implemented by the UI elements that represent
a top-level window, such as the main window of an application or
dialog.
See [classObject]
Signals
activate
The signal activate is emitted when a window
becomes the active window of the application or session.
create
The signal create is emitted when a new window
is created.
deactivate
The signal deactivate is emitted when a window is
no longer the active window of the application or session.
destroy
The signal destroy is emitted when a window is
destroyed.
maximize
The signal maximize is emitted when a window
is maximized.
minimize
The signal minimize is emitted when a window
is minimized.
move
The signal move is emitted when a window
is moved.
resize
The signal resize is emitted when a window
is resized.
restore
The signal restore is emitted when a window
is restored.
Object
active-descendant-changed
The “active-descendant-changed” signal is emitted by an object which has the state ATK_STATE_MANAGES_DESCENDANTS when the focus object in the object changes. For instance, a table will emit the signal when the cell in the table which has focus changes.
Detailed
announcement
The “announcement” signal can be emitted to pass an announcement on to be read by a screen reader.
Depcrecated (2.50): Use AtkObject::notification instead.
children-changed
The signal “children-changed” is emitted when a child is added or removed form an object. It supports two details: “add” and “remove”
Detailed
focus-event
The signal “focus-event” is emitted when an object gained or lost focus.
notification
The “notification” signal can be emitted to pass an announcement on to be read by a screen reader.
property-change
The signal “property-change” is emitted when an object’s property
value changes. arg1 contains an AtkPropertyValues with the name
and the new value of the property whose value has changed. Note
that, as with GObject notify, getting this signal does not
guarantee that the value of the property has actually changed; it
may also be emitted when the setter of the property is called to
reinstate the previous value.
Toolkit implementor note: ATK implementors should use
ObjectExt::notify() to emit property-changed
notifications. property-changed is needed by the
implementation of atk_add_global_event_listener() because GObject
notify doesn’t support emission hooks.
Detailed
state-change
The “state-change” signal is emitted when an object’s state changes. The detail value identifies the state type which has changed.
Detailed
visible-data-changed
The “visible-data-changed” signal is emitted when the visual appearance of the object changed.
Implements
Implementations